@@ -61,7 +61,7 @@ selectizeGroupUI <- function(id, params, label = NULL, btn_label = "Reset filter
       actionLink(
         inputId = ns("reset_all"),
         label = btn_label,
-        icon = icon("times"),
+        icon = icon("xmark"),
         style = "float: right;"
       )
     )
@@ -94,7 +94,7 @@ selectizeGroupUI <- function(id, params, label = NULL, btn_label = "Reset filter
       actionLink(
         inputId = ns("reset_all"),
         label = btn_label,
-        icon = icon("times"),
+        icon = icon("xmark"),
         style = "float: right;"
       )
     )
