@@ -23,7 +23,7 @@
     if (is.null(data)) {
       NULL
     } else {
-      res <- try(as.Date(unlist(data)), silent = TRUE)
+      res <- try(anytime::anydate(unlist(data)), silent = TRUE)
       if ("try-error" %in% class(res)) {
         warning("Failed to parse dates!")
         # as.Date(NA)
@@ -34,13 +34,10 @@
     }
   }, force = TRUE)
   shiny::registerInputHandler("air.datetime", function(data, ...) {
-    parse_datetime <- function(x) {
-      as.POSIXct(x = x/1000, origin = "1970-01-01")
-    }
     if (is.null(data)) {
       NULL
     } else {
-      res <- try(parse_datetime(unlist(data)), silent = TRUE)
+      res <- try(anytime::anytime(unlist(data)), silent = TRUE)
       if ("try-error" %in% class(res)) {
         warning("Failed to parse dates!")
         # as.Date(NA)
