@@ -1,3 +1,8 @@
+/*jshint
+  jquery:true
+*/
+/*global noUiSlider, wNumb, Shiny, updateLabel */
+
 // noUiSlider bindings by VP //
 
 var noUiSliderBinding = new Shiny.InputBinding();
@@ -25,7 +30,7 @@ $.extend(noUiSliderBinding, {
       .find('script[data-for="' + Shiny.$escape(el.id) + '"]');
     config = JSON.parse(config.html());
     if (typeof config.format !== "undefined") {
-      numformat = wNumb(config.format);
+      var numformat = wNumb(config.format);
       if (Array.isArray(values)) {
         result = values.map(numformat.from);
       } else {
@@ -68,6 +73,10 @@ $.extend(noUiSliderBinding, {
     $(el).off(".noUiSliderBinding");
   },
   receiveMessage: function receiveMessage(el, data) {
+    if (data.hasOwnProperty("label")) {
+      var label = $("#" + el.id + "-label");
+      updateLabel(data.label, label);
+    }
     var slider = document.getElementById(el.id);
     if (data.disable) {
       slider.setAttribute("disabled", true);
@@ -98,9 +107,23 @@ $.extend(noUiSliderBinding, {
       .parent()
       .find('script[data-for="' + Shiny.$escape(el.id) + '"]');
     config = JSON.parse(config.html());
-    if (typeof config.format !== "undefined") {
+    if (config.hasOwnProperty("format")) {
       config.format = wNumb(config.format);
     }
+    if (config.hasOwnProperty("pips")) {
+      if (config.pips.hasOwnProperty("format")) {
+        config.pips.format = wNumb(config.pips.format);
+      }
+      if (config.pips.hasOwnProperty("size")) {
+        config.pips.filter = function(value, type) {
+          if (type > 0) {
+            return config.pips.size;
+          } else {
+            return type;
+          }
+        };
+      }
+    }
     var slider = document.getElementById(el.id);
     if (config.orientation === "vertical") {
       slider.style.margin = "0 auto 30px";
@@ -109,5 +132,5 @@ $.extend(noUiSliderBinding, {
   }
 });
 
-Shiny.inputBindings.register(noUiSliderBinding, "shiny.noUiSlider");
+Shiny.inputBindings.register(noUiSliderBinding, "shinyWidgets.noUiSlider");
 
